@@ -33,21 +33,21 @@ class Domoticz(IPlugin):
 		if jsonInput['outcome']['entities']['location']['body'] :
 			location = jsonInput['outcome']['entities']['location']['body']
 		else:
-			bod = "pas de lieu"
+			bodies = "pas de lieu"
 
 		if jsonInput['outcome']['entities']['on_off']['value'] :
 			on_off = jsonInput['outcome']['entities']['on_off']['value']
 		else:
-			bod = "pas de on/off"
+			bodies = "pas de on/off"
 #
 		idex= location + "_" + on_off
 		#log.msg("WAMP session data received (transport ID %s): %s" % (self._parent._transportid, payload))
 		log.msg("index :  %s" % (idex)		
 #		for rs in self.configuration_plugin['param_dz']
 #			if rs['ids'] == idex
-#				bod == rs['boy']
+#				bodies == rs['boy']
 #				resp = requests.get ('http://192.168.0.3:8080/json.htm?type=command&param=switchlight&idx=%02d&switchcmd=%s&level=0' % (rs[idx],on_off.capitalize()))
 		return {"plugin": "Domoticz",
-			"method": "switchlight"
-			"body": bod
+			"method": "switchlight",
+			"body": bodies
 		}
